@@ -56,6 +56,8 @@ class X11SessionTestCase(DBusTestCase):
     @classmethod
     def setUpClass(klass):
         klass.start_xorg()
+        klass.addClassCleanup(klass.stop_xorg)
+
         klass.start_system_bus()
         klass.start_session_bus()
 
@@ -109,11 +111,10 @@ class X11SessionTestCase(DBusTestCase):
         if hasattr(klass, 'xorg'):
             klass.X_display = -1
             klass.xorg.terminate()
-            klass.xorg.wait()
+            try:
+                klass.xorg.wait(1)
+            except:
+                klass.xorg.kill()
+                klass.xorg.wait()
             del klass.xorg
 
-    @classmethod
-    def tearDownClass(klass):
-        DBusTestCase.tearDownClass()
-
-        klass.stop_xorg()
